window[buttonmode="hideOne"] input#ButtonOne,
window[buttonmode="hideAll"] input#ButtonOne
{
display:none;
}

window[buttonmode="hideTwo"] input#ButtonTwo,
window[buttonmode="hideAll"] input#ButtonTwo
{
display:none;
}